from typing import *


class PeriodArray:

    # usage.dask: 1
    asi8: object

    # usage.dask: 1
    dtype: object

    def __add__(self, _0: Union[numpy.ndarray, numpy.timedelta64, numpy.datetime64], /):
        """
        usage.pandas: 5
        """
        ...

    def __eq__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 6
        """
        ...

    def __ge__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 6
        """
        ...

    def __gt__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 4
        """
        ...

    def __le__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 6
        """
        ...

    def __lt__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 2
        """
        ...

    def __ne__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 6
        """
        ...

    def __radd__(
        self, _0: Union[numpy.ndarray, numpy.datetime64, numpy.timedelta64], /
    ):
        """
        usage.pandas: 4
        """
        ...

    def __rsub__(
        self, _0: Union[numpy.ndarray, numpy.datetime64, numpy.timedelta64], /
    ):
        """
        usage.pandas: 4
        """
        ...

    def __sub__(self, _0: Union[numpy.ndarray, numpy.datetime64, numpy.timedelta64], /):
        """
        usage.pandas: 8
        """
        ...
